<?php

namespace App\Admin\Controllers;

use App\Admin\Repositories\BaseProductCategory;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Http\Controllers\AdminController;
use Dcat\Admin\Layout\Content;
use App\Admin\Repositories\BaseProductParameter;

class BaseProductCategoryController extends AdminController
{

    public function index(Content $content)
    {
        return $content
            ->header('Product Category')
            ->description('')
            ->body($this->grid());
    }


    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(BaseProductCategory::with('baseProductParameter'), function (Grid $grid) {
            $grid->column('id','ID')->bold()->sortable();
            $grid->column('name')->display(function ($name) {
                $level = $this->level; // 获取当前行的 level 字段值
                $prefix = str_repeat('&nbsp; ', $level * 2). ' <i class="fa fa-angle-right"></i>&nbsp; '; // 生成 level * 3 个加号
                return $prefix . ' ' . html_entity_decode($name); // 拼接加号和名称
            });;
            $grid->column('parent_id');
            $grid->column('baseProductParameter.name',admin_trans_label('parameter_name'));
            $grid->column('order');
            $grid->column('enabled')->switch();
            $grid->column('created_at');
            $grid->column('updated_at')->sortable();
            //过滤器
            $grid->filter(function (Grid\Filter $filter) {
                $filter->panel();
                $filter->expand();
                $filter->like('name')->width(2);
                $filter->equal('enabled', admin_trans_label('Enabled'))->select(config('dictionary.enabled'))->width(2);
            });
            //工具栏
            $grid->disableViewButton();
            $grid->showQuickEditButton();
            $grid->enableDialogCreate();
            $grid->disableEditButton();
            //$grid->quickSearch('name');
        });

    }


    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new BaseProductCategory(), function (Form $form) {
            $form->display('id', 'ID');
            $form->select('parent_id', admin_trans_field('parent'))
                ->options(BaseProductCategory::selectMainOptions(function ($query) {
                    // 在这里定义查询条件
                    $query->where('parent_id', 0);
                }))
                ->saving(function ($v) {
                    return (int) $v;
                });
            $form->text('name')->required();
            $form->select('parameter_id', admin_trans_field('parameter_name'))->options(BaseProductParameter::selectOptions())->required();
            $form->number('order')
                ->default(100)
                ->rules('numeric')
                ->help(admin_trans_label('order_tips')); // 添加备注
            $form->switch('enabled')->default(1);
          //  $form->display('created_at');
          //  $form->display('updated_at');
        });
    }
}
